@extends('front.layout')
@section('title')
{{__('Show order')}}
@endsection
@section('css')
<link href="{{url('assets/front/css/cart.css')}}" rel="stylesheet">
<link href="{{url('assets/front/css/checkout.css')}}" rel="stylesheet">

@endsection
@section('content')
<main class="bg_gray">
    <div class="container margin_30">
        <div class="page_header">
            <div class="breadcrumbs">
                <ul>
                    <li><a href="{{url('/')}}">{{__('Home')}}</a></li>
                    <li><a href="{{route('orders')}}">{{__('Orders')}}</a></li>
                    <li>{{__('Return Details')}}</li>
                </ul>
            </div>
        </div>
        <!-- /page_header -->
        
        <div class="row rtl" style="background-color: white">
            <div class="col-lg-12">
                <h4 class="pb-3 title_heading">{{__('Return requests')}}</h4> 
                <div class="overflow">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>{{__('Created at')}}</th>
                                <th class="text-center">
                                    {{__('Status')}}
                                </th>
                                <th class="text-center">
                                    {{__('Cancel')}}
                                </th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($order['returns'] as $return)
                            <tr>
                                <td>
                                    {{date('d-m-Y',strtotime($return['created_at']))}}
                                </td>
                                <td width="50px">
                                    @if($return['status'])
                                        <p class="text-success">{{__('Done')}}</p>
                                    @else 
                                        <p class="text-primary">{{__('Waiting')}}</p>
                                    @endif
                                </td>
                                <td width="100px" class="text-center">
                                    @if(!$return['status'])
                                    <div style="width: 100px">
                                        <a href="{{route('orders.return_delete',$return['id'])}}" class="text-danger">
                                            <i class="fa fa-trash"></i>
                                        </a>
                                    </div>
                                    @else 
                                        <span>{{__('Not Available')}}</span>
                                    @endif
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <br>
        @if($order['status']==3)
        <form action="{{route('orders.return_products_submit',$order['id'])}}" method="POST" id="return_form">
            @csrf
            <div class="row" style="background-color: white">
                <div class="col-lg-12">
                    <div class="row rtl">
                        <div class="col-lg-12">
                            <h4 class="pb-3 title_heading">{{__('Request return now')}}</h4>
                        </div> 
                    </div>
                    <div class="row rtl" style="overflow-x:auto;">
                        <div class="col-lg-12">
                            <table class="table">
                                <thead>
                                    <tr>
                                        <th>
                                            {{__('Product')}}
                                        </th>
                                        <th>
                                            {{__('Description')}}
                                        </th>
                                        <th>
                                            {{__('Quantity')}}
                                        </th>
                                        <th>
                                            {{__('Price')}}
                                        </th>
                                        <th>
                                            {{__('Commission')}}
                                        </th>
                                        <th>
                                            {{__('Return quantity')}}
                                        </th>
                                        <th>
                                            {{__('Reason')}}
                                        </th>
                                    </tr>
                                </thead>
                                <tbody>
                                        @foreach($order->order_products as $product)
                                            @if($product['quantity']-$product['return_quantity']>0)
                                            <tr>
                                                <td>
                                                    <span class="item_cart product">{{$product->product->name}}</span>
                                                    <input type="hidden" value="{{$product['id']}}" name="product[{{$product['id']}}][product]">
                                                </td>
                                                <td>
                                                    <div class="desc">
                                                        <ul>
                                                            @foreach($product->options as $option)
                                                                <li>
                                                                    <strong>{{$option['option']['attribute']['name']}}:</strong>
                                                                    {{$option['option']['name']}}
                                                                </li>
                                                            @endforeach
                                                        </ul>
                                                    </div>
                                                </td>
                                                <td>
                                                    {{$product->quantity}}
                                                </td>
                                                <td>
                                                    <p class="product_price">{{formated_price($product->price)}}</p>
                                                </td>
                                                <td>
                                                    <p class="product_price">{{formated_price($product->commission)}}</p>
                                                </td>
                                                <td>
                                                    <input type="number" style="width:150px" name="product[{{$product['id']}}][quantity]" min="1" max="{{$product['quantity']-$product['return_quantity']}}" id="" value="1" class="form-control" required>
                                                </td>
                                                <td>
                                                    <textarea style="width:200px!important" name="product[{{$product['id']}}][reason]"  placeholder="{{__('Return reason')}}" class="form-control"  rows="5" required></textarea>
                                                </td>
                                            
                                            </tr>
                                            @endif
                                        @endforeach
                                </tbody>
                                
                            </table>
                        </div>
                        <!-- /cart_actions -->
                    </div>
                    <div class="row rtl">
                        <div class="col-lg-12">
                            <button type="submit" class="btn_1">
                                {{__('Save')}}
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </form>
        @endif
    </div>
    <!-- /container -->
</main>
@endsection
@section('scripts')
<script>
     $(document).ready(function(){
        $('#return_form').validate();
     });
</script>
@endsection